Wraps text in a character matrix so that it's displayed over more than one line.
Details
A data.frame containing character columns with long texts is often wrapped
by columns. This can lead to a loss of overview. columnWrap() wraps the
lines within the columns.
See also
Other data.print:
printCharMatrix()
Examples
print(columnWrap("This is a very long text for a table", 12))
#> [,1]
#> [1,] "This is a"
#> [2,] "very long"
#> [3,] "text for a"
#> [4,] "table"