Calculate the proper divisors of positive natural numbers.
Value
an integer vector containing the proper divisors in ascending
order if x is a single number, otherwise a named list of such
vectors. A prime number yields 1, and 1 itself yields
integer(0) - its only divisor is 1, which is x itself and
therefore not a proper one.
Details
Divisibility is a mathematical relationship between two integers. An integer
is divisible by another integer if there is no remainder in the division.
This function returns the proper divisors of x, i.e. all
positive divisors excluding x itself. The number 11 is prime and has
only the proper divisor 1, whereas the number 12 has the proper divisors
1, 2, 3, 4 and 6. In elementary number theory, the concept of divisibility
is limited to natural numbers. The number of proper divisors can be
determined with the function length().
See also
Other number.theory:
GCD-LCM,
digitSum(),
factorize(),
fibonacci(),
isOdd(),
isPrime(),
primes()