Returns the full path to a file located in the user's Downloads directory.
Details
The function resolves the path to the user's Downloads directory using
an internal helper and appends file. It does not perform any
downloading; it only locates files that already exist locally.
If the file does not exist, an error is thrown.
See also
Other file.path:
buildPath(),
fileExistURL(),
isFilePath(),
isURL(),
splitPath()