For screening purposes it can be useful to get a list of all function calls
our function may depend on. funCalls() parses the function
source and returns all found function calls grouped by their package.
Value
a list of character vectors with the function calls, grouped by the environment the called functions were found in.
Details
The source packages are resolved via find(), which only
sees attached packages. Calls to functions from packages that are not on
the search path are reported under "<not found>".
See also
Other pkg.funinfo:
funArgs(),
funKeywords(),
funList(),
rdLabels(),
rdTitle()