List the keywords for specific R man pages or return a list of valid R keywords.
Value
if topic is missing, the R keywords documentation file is
opened for display via file.show(), invisibly
returning NULL. Otherwise, a character vector of topic names
whose keywords match topic.
Details
If topic is provided, return a list of the Keywords associated with
topic. Otherwise, display the list of valid R Keywords from the R
doc/Keywords file.
Note
Substantially based on the keywords() function from the
gtools package by Gregory R. Warnes, with minor adaptations by the
package author.
See also
Other pkg.funinfo:
funArgs(),
funCalls(),
funList(),
rdLabels(),
rdTitle()