Test if x is zero. This is done by checking if the numeric value is below the machine tolerance.
Usage
isZero(x, tol = sqrt(.Machine$double.eps), na.rm = FALSE)Value
logical vector of the same length as x (after optional
NA removal). Non-numeric input yields all-FALSE.
References
Burns, P. (2011). The R Inferno. https://www.burns-stat.com/documents/books/the-r-inferno/
See also
Other data.predicate:
flags(),
isDichotomous(),
isEuclid(),
isLowCardinality(),
isNumeric(),
isWholeLike(),
nUnique()