PDF versions of the manual are usually not included as vignettes in R
packages. Still this format is convenient for reading and doing full text
search.
This function creates the appropriate link to the pdf file on
CRAN and opens the pdf manual in a browser window.
Details
A warning (not an error) is issued if the package is not installed locally, as the manual may well exist on CRAN anyway.
See also
Other file.io:
parseSASDatalines(),
peekFile(),
readDownload()