Generates a vector of random proportions that sum exactly to 1.
Details
The values are drawn from a uniform distribution and normalized by their
sum. If digits is given, the values are rounded and the rounding
error is assigned to the largest element, which is then rounded again to
the requested precision. Note that for very coarse rounding the exact-sum
guarantee may not be attainable at the given precision.
See also
Other random.numbers:
rBetaShape()