Searches all .Rd files in a package's man/ directory for a
given topic (matched against \\alias entries) and returns its
\\title string.
Value
a single character string with the title, trimmed of leading and
trailing whitespace. Stops with an error if topic is not found.
See also
Other pkg.funinfo:
funArgs(),
funCalls(),
funKeywords(),
funList(),
rdLabels()